
# SiEPIC_EBeam_PDK

- Developed as part of the <a href="www.siepic.ubc.ca">SiEPIC</a> program, the SiEPIC EBeam PDK is a process design kit (PDK) for fabrication using electron beam lithography, and a library silicon photonics components.

- Instruction on design, layout, fabrication, test, data analysis for silicon photonics provided in the edX course: <a href="http://edx.org/course/silicon-photonics-design-fabrication-ubcx-phot1x">Silicon Photonics Design, Fabrication and Data Analysis</a> and textbook <a href="http://www.cambridge.org/ca/academic/subjects/engineering/electronic-optoelectronic-devices-and-nanotechnology/silicon-photonics-design-devices-systems">Silicon Photonics Design: From Devices to Systems</a> by Lukas Chrostowski and Michael Hochberg.


## Download and Installation instructions:
 - Details are provided in the Wiki page: <a href="https://github.com/siepic/SiEPIC_EBeam_PDK/wiki/Installation-instructions">Installation instructions</a>. KLayout's package manager is used for both downloading and installing the package into the KLayout Application.
 - The PDK may also be installed using pip install siepic_ebeam_pdk

 
